@@ -19,7 +19,8 @@ from .base_entry_factory import BaseEntryFactory
 from .base_entry_relationship_mapper import BaseEntryRelationshipMapper
 from .base_tag_factory import BaseTagFactory
 from .base_tag_template_factory import BaseTagTemplateFactory
+from .datacatalog_strings_helper import DataCatalogStringsHelper
 
 __all__ = ('AssembledEntryData', 'BaseEntryFactory',
            'BaseEntryRelationshipMapper', 'BaseTagFactory',
-           'BaseTagTemplateFactory')
+           'BaseTagTemplateFactory', 'DataCatalogStringsHelper')
